==> hexo-theme-keep-4.1.1.tgz: package/docs/README_zh-TW.md <==
<div align="right">
  語言：
  繁體中文 | 
  <a title="English" href="../README.md">English</a> | 
  <a title="简体中文" href="README_zh-CN.md">简体中文</a>
</div>

<a href="https://xpoet.cn"><img align="center" alt="Keep" src="https://keep-docs.xpoet.cn/images/keep-slogan.svg"></a>

# hexo-theme-keep

**Keep** 是一款簡約輕快的 [Hexo](https://hexo.io) 主題。它能讓你更專注於寫作。

[![Github License](https://img.shields.io/github/license/XPoet/hexo-theme-keep?style=flat-square&logo=github&color=3366cc)](https://github.com/XPoet/hexo-theme-keep/blob/master/LICENSE)
[![Github Release](https://img.shields.io/github/release/XPoet/hexo-theme-keep?style=flat-square&logo=github&color=mediumpurple)](https://github.com/XPoet/hexo-theme-ils/releases)
[![NPM Version](https://img.shields.io/npm/v/hexo-theme-keep?style=flat-square&logo=npm&color=indianred)](https://www.npmjs.com/package/hexo-theme-keep)
[![NPM Downloads](https://img.shields.io/npm/dw/hexo-theme-keep?style=flat-square&logo=npm&color=darkorange)](https://www.npmjs.com/package/hexo-theme-keep)
[![Node.js Version](https://img.shields.io/badge/node-%3E=14.0.0-forestgreen?style=flat-square&logo=Node.js)](https://nodejs.org)
[![Required Hexo version](https://img.shields.io/badge/hexo-%3E=5.0.0-steelblue?style=flat-square&logo=hexo)](https://hexo.io)

## :star2: 線上預覽

- **[XPoet's Blog](https://xpoet.cn/)**
- **[keep 預覽](https://keep.xpoet.cn/)**

> 如果你想把自己的博客鏈接放在線上預覽列表裏，可以給作者提 PR。

## :books: 文檔

請查看 **Keep** 官方文檔：

- **[Keep 官方文檔](https://keep-docs.xpoet.cn/)**
- **[Keep 主題配置指南](https://keep-docs.xpoet.cn/basis/configuration-guide/base_info.html)**
- **[Keep 主題進階使用](https://keep-docs.xpoet.cn/advanced/set-language.html)**

## :rocket: 安装

如果你使用 Hexo 5.0 或更高版本，最簡單的安裝方式是透過 NPM：

```sh
# 推薦

cd your-hexo
npm install hexo-theme-keep
```

你也可以直接 clone 整個原始碼庫：

```sh
cd your-hexo
git clone https://github.com/XPoet/hexo-theme-keep --depth=1 themes/keep
```

安裝完成後，在 Hexo 配置文件中將 `theme` 設定為 `keep`。

```yml
theme: keep
```

## :tada: 更新

**Keep** 不定期發布新版本。你可以透過如下命令更新 **Keep**。

透過 NPM 安裝最新版本：

```sh
# 推薦

$ cd your-hexo
$ npm install hexo-theme-keep@latest
```

或者透過 git 更新到最新的 master 分支：

```sh
$ cd themes/keep
$ git pull
```

不推薦直接修改 **Keep** 主題的文件。因為這可能導致錯誤（例如 git merge 衝突），並且在更新主題時修改的文件可能丟失。

## :art: 貢獻者

這個項目的存在多虧了所有的貢獻者。

<a href="https://github.com/XPoet/hexo-theme-keep/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=XPoet/hexo-theme-keep" />
</a>

我們歡迎你加入 **Keep** 的開發，貢獻出你的一份力量。請看 [Keep 原始碼貢獻指南](https://keep-docs.xpoet.cn/user-notice/contribution-guide.html)。

## :sparkling_heart: 銘謝

**Keep** 特别感謝這些支持我們核心基本設施的優質服務：

- [GitHub](https://github.com) 允許我們存放 Git 原始碼庫及運行測試。
- [cdnjs](https://cdnjs.com)、[jsDelivr](https://www.jsdelivr.com) 和 [UNPKG](https://www.unpkg.com) 提供了 CDN 服務。

## :memo: 許可

[AGPL-3.0](https://github.com/XPoet/hexo-theme-keep/blob/master/LICENSE)  

Copyright © 2020-present XPoet

==> hexo-theme-keep-4.2.5.tgz: package/docs/README_zh-TW.md <==
<div align="right">
  語言：
  繁體中文 | 
  <a title="English" href="../README.md">English</a> | 
  <a title="简体中文" href="README_zh-CN.md">简体中文</a>
</div>

<a href="https://xpoet.cn"><img align="center" alt="Keep" src="https://keep-docs.xpoet.cn/images/keep-slogan.svg"></a>

# hexo-theme-keep

**Keep** 是一款簡約輕快的 [Hexo](https://hexo.io) 主題，它能讓你更專注於寫作。

[![Github License](https://img.shields.io/github/license/XPoet/hexo-theme-keep?style=flat-square&logo=github&color=3366cc)](https://github.com/XPoet/hexo-theme-keep/blob/master/LICENSE)
[![Github Release](https://img.shields.io/github/release/XPoet/hexo-theme-keep?style=flat-square&logo=github&color=mediumpurple)](https://github.com/XPoet/hexo-theme-ils/releases)
[![NPM Version](https://img.shields.io/npm/v/hexo-theme-keep?style=flat-square&logo=npm&color=indianred)](https://www.npmjs.com/package/hexo-theme-keep)
[![NPM Downloads](https://img.shields.io/npm/dw/hexo-theme-keep?style=flat-square&logo=npm&color=darkorange)](https://www.npmjs.com/package/hexo-theme-keep)
[![Node.js Version](https://img.shields.io/badge/node-%3E=14.0.0-forestgreen?style=flat-square&logo=Node.js)](https://nodejs.org)
[![Required Hexo version](https://img.shields.io/badge/hexo-%3E=5.0.0-steelblue?style=flat-square&logo=hexo)](https://hexo.io)

## :star2: 線上預覽

- **[XPoet's Blog](https://xpoet.cn/)**
- **[Keep 預覽](https://keep.xpoet.cn/)**

> 如果你想把自己的部落格連結放在線上預覽列表裏，可以給作者提 PR。

## :books: 文檔

請查看 **Keep** 官方文檔：

- **[Keep 官方文檔](https://keep-docs.xpoet.cn/)**
- **[Keep 主題配置指南](https://keep-docs.xpoet.cn/basis/configuration-guide/base_info.html)**
- **[Keep 主題進階用法](https://keep-docs.xpoet.cn/advanced/set-language.html)**

## :rocket: 安装

如果你使用 Hexo 5.0 或更高版本，最簡單的安裝方式是透過 NPM：

```sh
# 推薦

cd your-hexo
npm install hexo-theme-keep
```

你也可以直接 clone 整個原始碼庫：

```sh
cd your-hexo
git clone https://github.com/XPoet/hexo-theme-keep --depth=1 themes/keep
```

安裝完成後，在 Hexo 配置文件中將 `theme` 設定為 `keep`。

```yml
theme: keep
```

## :tada: 更新

**Keep** 不定期發布新版本。你可以透過如下命令更新 **Keep**。

透過 NPM 安裝最新版本：

```sh
# 推薦

$ cd your-hexo
$ npm install hexo-theme-keep@latest
```

或者透過 git 更新到最新的 master 分支：

```sh
$ cd themes/keep
$ git pull
```

不推薦直接修改 **Keep** 主題的文件。因為這可能導致錯誤（例如 git merge 衝突），並且在更新主題時修改的文件可能丟失。

## :art: 貢獻者

這個項目的存在多虧了所有的貢獻者。

<a href="https://github.com/XPoet/hexo-theme-keep/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=XPoet/hexo-theme-keep" />
</a>

我們歡迎你加入 **Keep** 的開發，貢獻出你的一份力量。請查看 [Keep 原始碼貢獻指南](https://keep-docs.xpoet.cn/user-notice/contribution-guide.html)。

## :sparkling_heart: 銘謝

**Keep** 特别感謝這些支持我們核心基本設施的優質服務：

- [GitHub](https://github.com) 允許我們存放 Git 原始碼庫及運行測試。
- [cdnjs](https://cdnjs.com)、[jsDelivr](https://www.jsdelivr.com) 和 [UNPKG](https://www.unpkg.com) 提供了 CDN 服務。

## :memo: 許可

[AGPL-3.0](https://github.com/XPoet/hexo-theme-keep/blob/master/LICENSE)

Copyright © 2020-present XPoet
